@@ -63,7 +63,7 @@ def parse_url(url, blen=100):
 
     return bshot
 
-    
+
 def getlastshot():
     """
     Gets last shot number from the AUG webpage(s)
@@ -182,10 +182,14 @@ class SFREAD:
 
         if 'exp' in kwargs.keys():
             exp = kwargs['exp']
+        elif 'experiment' in kwargs.keys():
+            exp = kwargs['experiment']
         else:
             exp = 'AUGD'
         if 'ed' in kwargs.keys():
             ed = kwargs['ed']
+        elif 'edition' in kwargs.keys():
+            ed = kwargs['edition']
         else:
             ed = 0
 
@@ -212,17 +216,18 @@ class SFREAD:
 
 
     def __call__(self, name):
+
         if not self.status:
             return None
+        if name not in self.cache.keys():
+            if name in self.objects:
+                self.cache[name] = self.getobject(name)
+            if name in self.parsets:
+                self.cache[name] = self.getparset(name)
         if name in self.cache.keys():
             return self.cache[name]
-        if name in self.objects:
-            self.cache[name] = self.getobject(name)
-            return self.getobject(name)
-        if name in self.parsets:
-            self.cache[name] = self.getparset(name)
-            return self.getparset(name)
-        return None
+        else:
+            return None
 
 
     def getchunk(self, start, length):
@@ -281,6 +286,9 @@ class SFREAD:
         data = None
         if obj not in self.sfh.keys():
             return None
+# Don't uncomment the following lines, to allow 1 cal and 1 uncal reading
+#        if obj in self.cache.keys(): 
+#            return cache[obj]
 
         sfo = self.sfh[obj]
         if sfo.status != 0:
@@ -313,7 +321,8 @@ class SFREAD:
                     sfmt = sfdics.fmt2struc[dfmt]
                     dt  = np.dtype(sfdics.fmt2np[dfmt])
                     dt = dt.newbyteorder('>')
-                    bytlen = np.prod(shape_arr) * np.dtype(sfmt).itemsize
+                    type_len = np.dtype(sfmt).itemsize
+                    bytlen = np.prod(shape_arr) * type_len
                     data = np.ndarray(shape_arr, '>%s' %sfmt, self.getchunk(sfo.address, bytlen), order='F')
 
 # LongLong in [ns] and no zero at TS06
